Class: Google::Apis::DatastoreV1beta3::MutationResult
- Inherits:
-
Object
- Object
- Google::Apis::DatastoreV1beta3::MutationResult
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datastore_v1beta3/classes.rb,
lib/google/apis/datastore_v1beta3/representations.rb,
lib/google/apis/datastore_v1beta3/representations.rb
Overview
The result of applying a mutation.
Instance Attribute Summary collapse
-
#conflict_detected ⇒ Boolean
(also: #conflict_detected?)
Whether a conflict was detected for this mutation.
-
#create_time ⇒ String
The create time of the entity.
-
#key ⇒ Google::Apis::DatastoreV1beta3::Key
A unique identifier for an entity.
-
#transform_results ⇒ Array<Google::Apis::DatastoreV1beta3::Value>
The results of applying each PropertyTransform, in the same order of the request.
-
#update_time ⇒ String
The update time of the entity on the server after processing the mutation.
-
#version ⇒ Fixnum
The version of the entity on the server after processing the mutation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MutationResult
constructor
A new instance of MutationResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MutationResult
Returns a new instance of MutationResult.
1659 1660 1661 |
# File 'lib/google/apis/datastore_v1beta3/classes.rb', line 1659 def initialize(**args) update!(**args) end |
Instance Attribute Details
#conflict_detected ⇒ Boolean Also known as: conflict_detected?
Whether a conflict was detected for this mutation. Always false when a
conflict detection strategy field is not set in the mutation.
Corresponds to the JSON property conflictDetected
1621 1622 1623 |
# File 'lib/google/apis/datastore_v1beta3/classes.rb', line 1621 def conflict_detected @conflict_detected end |
#create_time ⇒ String
The create time of the entity. This field will not be set after a 'delete'.
Corresponds to the JSON property createTime
1627 1628 1629 |
# File 'lib/google/apis/datastore_v1beta3/classes.rb', line 1627 def create_time @create_time end |
#key ⇒ Google::Apis::DatastoreV1beta3::Key
A unique identifier for an entity. If a key's partition ID or any of its path
kinds or names are reserved/read-only, the key is reserved/read-only. A
reserved/read-only key is forbidden in certain documented contexts.
Corresponds to the JSON property key
1634 1635 1636 |
# File 'lib/google/apis/datastore_v1beta3/classes.rb', line 1634 def key @key end |
#transform_results ⇒ Array<Google::Apis::DatastoreV1beta3::Value>
The results of applying each PropertyTransform, in the same order of the
request.
Corresponds to the JSON property transformResults
1640 1641 1642 |
# File 'lib/google/apis/datastore_v1beta3/classes.rb', line 1640 def transform_results @transform_results end |
#update_time ⇒ String
The update time of the entity on the server after processing the mutation. If
the mutation doesn't change anything on the server, then the timestamp will be
the update timestamp of the current entity. This field will not be set after a
'delete'.
Corresponds to the JSON property updateTime
1648 1649 1650 |
# File 'lib/google/apis/datastore_v1beta3/classes.rb', line 1648 def update_time @update_time end |
#version ⇒ Fixnum
The version of the entity on the server after processing the mutation. If the
mutation doesn't change anything on the server, then the version will be the
version of the current entity or, if no entity is present, a version that is
strictly greater than the version of any previous entity and less than the
version of any possible future entity.
Corresponds to the JSON property version
1657 1658 1659 |
# File 'lib/google/apis/datastore_v1beta3/classes.rb', line 1657 def version @version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1664 1665 1666 1667 1668 1669 1670 1671 |
# File 'lib/google/apis/datastore_v1beta3/classes.rb', line 1664 def update!(**args) @conflict_detected = args[:conflict_detected] if args.key?(:conflict_detected) @create_time = args[:create_time] if args.key?(:create_time) @key = args[:key] if args.key?(:key) @transform_results = args[:transform_results] if args.key?(:transform_results) @update_time = args[:update_time] if args.key?(:update_time) @version = args[:version] if args.key?(:version) end |